import re
import requests
from bs4 import BeautifulSoup


class Chat:
    def __init__(self):
        self.url = "https://funpay.com/chat/?node=flood"
        self.data = None

        self.__get_data__()

    def __get_data__(self):
        if self.data is None:
            response = requests.get(self.url)
            if response.status_code == 200:
                self.data = response.text
            else:
                raise Exception(f"Error getting data. Status code: {response.status_code}")
    
    def clean_text(self, text):
        return re.sub(r"\s+", " ", text)
    
    def chat_messages(self, max_limit=10):
        soup = BeautifulSoup(self.data, "html.parser")
        message_history = soup.find("div", class_="chat-message-list")
        dict_of_messages = {}
        i = 0
        for message in message_history.find_all("div", class_="chat-msg-item chat-msg-with-head") or message_history.find_all("div", class_="chat-msg-item"):
            if i == max_limit:
                break
            text = message.find("div", class_="chat-msg-text").text
            if text == "The message has been hidden." or text == "Сообщение скрыто.":
                continue
            sender = message.find("div", class_="media-user-name").find("a").text
            dict_of_messages[i] = {"sender": sender, "text": text}
            i += 1
        
        return dict_of_messages

class Home():
    def __init__(self):
        self.url = "https://funpay.com/"
        self.data = None

        self.__get_data__()

    def __get_data__(self):
        if self.data is None:
            response = requests.get(self.url)
            if response.status_code == 200:
                self.data = response.text
            else:
                raise Exception(f"Error getting data. Status code: {response.status_code}")
    
    def find_game(self, name: str = None):
        soup = BeautifulSoup(self.data, "html.parser")
        for i in soup.find_all("div", class_="game-title"):
            if name in i.text:
                return True, i.find("a")["href"]
        return False, None


import re
import requests
from bs4 import BeautifulSoup

class Chips():
    """
    Represents a Chips object.
    """

    def __init__(self, ID: int):
        """
        Initializes the Chips object.

        Args:
            ID (int): The ID of the chips.
        """
        self.id = str(ID)
        self.url = f"https://funpay.com/chips/{self.id}/"
        self.data = None

        self.__get_data__()

    def __get_data__(self):
        """
        Retrieves the raw HTML data of the chips.

        Returns:
            str: The raw HTML data of the chips.

        Raises:
            Exception: If there is an error getting the data.
        """
        if self.data is None:
            response = requests.get(self.url)
            if response.status_code == 200:
                self.data = response.text
            else:
                raise Exception(f"Error getting data for ID: {self.id}. Status code: {response.status_code}")
        return self.data

    def clean_text(self, text):
        """
        Cleans the given text by removing multiple whitespaces.

        Args:
            text (str): The text to be cleaned.

        Returns:
            str: The cleaned text.
        """
        return re.sub(r"\s+", " ", text)
    
    
    def chips_links(self, max_limit=10):
        """
        Returns a dictionary of chips links.

        Args:
            max_limit (int, optional): The maximum number of chips links to return. Defaults to 10.

        Returns:
            dict: A dictionary of chips links.
        """
        soup = BeautifulSoup(self.data, "html.parser")
        chips_list = soup.find("div", class_="tc table-hover table-clickable showcase-table tc-sortable tc-lazyload showcase-has-promo")
        chips = {}
        if chips_list:
            chips_list = chips_list.find_all("a", class_="tc-item")[:max_limit]
            for i, chip in enumerate(chips_list):
                href = chip.get("href")
                server = chip.find("div", class_="tc-server hidden-xxs").text
                seller = chip.find("div", class_="tc-user").find("div", class_="media-user-name").text
                amount = chip.find("div", class_="tc-amount").text.strip().replace(" ", "")
                price = chip.find("div", class_="tc-price").find("div").text.strip()

                chips[str(i+1)] = {
                    "href": href,
                    "server": self.clean_text(server),
                    "seller": self.clean_text(seller),
                    "amount": int(999831029) if str(amount) == "∞" else int(amount),
                    "price": float(price.split(sep=" ")[0])
                }
        return chips    




import re
import requests
from bs4 import BeautifulSoup


class Offers:
    """
    Class for scraping offers from funpay.com.

    Attributes:
        url (str): The URL for the offer.
        data (str or None): The raw HTML data of the offer.

    Methods:
        __get_data__(): Retrieves the raw HTML data of the offer.
        clean_text(text): Cleans the provided text.
        get_offer(): Returns a dictionary with the offer details.
    """
    def __init__(self, id):
        """
        Creates an instance of the Offers class.

        Args:
            id (int): The ID of the offer.
        """
        self.url = f"https://funpay.com/lots/offer?id={id}"
        self.data = None

        self.__get_data__()

    def __get_data__(self):
        """
        Retrieves the raw HTML data of the offer.

        Returns:
            str: The raw HTML data of the offer.

        Raises:
            Exception: If there is an error getting the data.
        """
        if self.data is None:
            response = requests.get(self.url)
            if response.status_code == 200:
                self.data = response.text
            else:
                raise Exception(f"Error getting data. Status code: {response.status_code}")
        return self.data

    def clean_text(self, text):
        """
        Cleans the provided text.

        Args:
            text (str): The text to be cleaned.

        Returns:
            str: The cleaned text.
        """
        return re.sub(r"\s+", " ", text).strip()

    def get_offer(self):
        """
        Returns a dictionary with the offer details.

        Returns:
            dict: A dictionary with the offer details.
                - auto_delivery (str): The availability of auto-delivery.
                - seller (str): The name of the seller.
                - cost_per_lot (str): The cost per lot.
        """
        soup = BeautifulSoup(self.data, "html.parser")
        auto_delivery = "available" if bool(soup.find("div", class_="offer-header-auto-dlv-label")) else "unavailable"
        seller = soup.find("div", class_="media-user-name").find("a").text
        payment_value = soup.find("span", class_="payment-value")
        cost_per_lot = payment_value.text.split("₽")[1].strip() if payment_value else "Undefined"

        return {
            "auto_delivery": auto_delivery,
            "seller": seller,
            "cost_per_lot": cost_per_lot
        }

